@@ -14,41 +14,41 @@ test_that("returns the correct linting", {
 
   expect_lint("'~'", NULL, absolute_paths_linter)
 
-  expect_lint("# 'C:/blah/file.txt'", NULL, absolute_paths_linter)
+  expect_lint("# 'C:/blah/file.txt'", NULL, absolute_paths_linter) # nolint
 
-  expect_lint("'/blah/file.txt'",
+  expect_lint("'/blah/file.txt'", # nolint
     rex("Do not use absolute paths."),
     absolute_paths_linter)
 
-  expect_lint("\"/blah/file.txt\"",
+  expect_lint("\"/blah/file.txt\"", # nolint
     rex("Do not use absolute paths."),
     absolute_paths_linter)
 
-  expect_lint("'c:/blah/file.txt'",
+  expect_lint("'c:/blah/file.txt'", # nolint
     rex("Do not use absolute paths."),
     absolute_paths_linter)
 
-  expect_lint("'C:/blah/file.txt'",
+  expect_lint("'C:/blah/file.txt'", # nolint
     rex("Do not use absolute paths."),
     absolute_paths_linter)
 
-  expect_lint("'E:/blah/file.txt'",
+  expect_lint("'E:/blah/file.txt'", # nolint
     rex("Do not use absolute paths."),
     absolute_paths_linter)
 
-  expect_lint("'E:\\blah\\file.txt'",
+  expect_lint("'E:\\blah\\file.txt'", # nolint
     rex("Do not use absolute paths."),
     absolute_paths_linter)
 
-  expect_lint("'~/blah/file.txt'",
+  expect_lint("'~/blah/file.txt'", # nolint
     rex("Do not use absolute paths."),
     absolute_paths_linter)
 
-  expect_lint("'~james.hester/blah/file.txt'",
+  expect_lint("'~james.hester/blah/file.txt'", # nolint
     rex("Do not use absolute paths."),
     absolute_paths_linter)
 
-  expect_lint("'~/'",
+  expect_lint("'~/'", # nolint
     rex("Do not use absolute paths."),
     absolute_paths_linter)
 })
